@@ -9,6 +9,11 @@ from coworks.cws.error import CwsCommandError
 
 class CwsCommand(click.Command, ABC):
 
+    @classmethod
+    def multi_execute(cls, project_dir, workspace, execution_params):
+        for command, options in execution_params:
+            command.execute(**options)
+
     def __init__(self, app: TechMicroService = None, *, name):
         super().__init__(name, callback=self._execute)
 
@@ -29,6 +34,12 @@ class CwsCommand(click.Command, ABC):
 
     def init_app(self, app):
         app.commands[self.name] = self
+        for cmd in self.needed_commands:
+            if cmd not in app.commands:
+                raise CwsCommandError(f"Undefined command {cmd} needed.")
+
+            for opt in self.app.commands[cmd].options:
+                opt(self)
 
     @property
     def needed_commands(self):
@@ -36,10 +47,7 @@ class CwsCommand(click.Command, ABC):
 
     @property
     def options(self):
-        opt = []
-        for cmd in self.needed_commands:
-            opt.extend(self.app.commands[cmd].options)
-        return opt
+        return []
 
     def execute(self, *, project_dir, module, service, workspace, output=None, error=None, **options):
         """ Called when the command is called.
@@ -50,9 +58,6 @@ class CwsCommand(click.Command, ABC):
         """
         self.app.deferred_init(workspace)
 
-        if output is None and 'output' in options:
-            output = options['output']
-
         if output is not None:
             self.output = open(output, 'w+') if type(output) is str else output
         if error is not None:
@@ -63,7 +68,9 @@ class CwsCommand(click.Command, ABC):
                 func(options)
 
             ctx = self.make_context(self.name, options)
-            ctx.params.update(project_dir=project_dir, module=module, service=service, workspace=workspace, **options)
+            ctx_options = {**options, 'output': output, 'error': error}
+            ctx.params.update(project_dir=project_dir, module=module, service=service, workspace=workspace,
+                              **ctx_options)
             self.invoke(ctx)
 
             for func in self.after_funcs:
