@@ -164,7 +164,6 @@ class CoworksMixin:
 
     def _create_auth_proxy(self, auth_method):
 
-        # @xray_recorder.capture('auth')
         def proxy(auth_activation):
             subsegment = xray_recorder.current_subsegment()
             try:
@@ -268,11 +267,10 @@ class CoworksMixin:
                 return _convert_response(resp)
 
             except Exception as e:
-                raise
-            finally:
                 subsegment = xray_recorder.current_subsegment()
                 if subsegment:
                     subsegment.add_error_flag()
+                raise
 
         proxy = update_wrapper(proxy, func)
         proxy.__cws_func__ = update_wrapper(partial(func, self), func)
